@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from __future__ import annotations
+
 import logging
 import re
 
@@ -35,12 +37,17 @@ class CatchErrors(base.ConfigurableMiddleware):
     """
 
     @webob.dec.wsgify
-    def __call__(self, req):
+    def __call__(
+        self,
+        req: webob.request.Request,
+    ) -> webob.response.Response | None:
         try:
             response = req.get_response(self.application)
         except Exception:
             req_str = _TOKEN_RE.sub(r'\1: *****', req.as_text())
-            LOG.exception('An error occurred during '
-                          'processing the request: %s', req_str)
+            LOG.exception(
+                'An error occurred during processing the request: %s',
+                req_str,
+            )
             response = webob.exc.HTTPInternalServerError()
         return response
