@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from __future__ import annotations
+
 import collections
 import gc
 import io
@@ -22,13 +24,14 @@ import platform
 import socket
 import sys
 import traceback
+import typing as ty
 
 from debtcollector import removals
 import jinja2
 from oslo_utils import reflection
-from oslo_utils import strutils
 from oslo_utils import timeutils
 import stevedore
+import typing_extensions as ty_ext
 import webob.dec
 import webob.exc
 import webob.response
@@ -42,17 +45,24 @@ from oslo_middleware import base
 from oslo_middleware.exceptions import ConfigInvalid
 from oslo_middleware.healthcheck import opts
 
+if ty.TYPE_CHECKING:
+    from _typeshed.wsgi import WSGIApplication
+    from oslo_config import cfg
+    from oslo_middleware.healthcheck import pluginbase
 
-def _find_objects(t):
+
+def _find_objects(t: type[ty.Any]) -> list[ty.Any]:
     return [o for o in gc.get_objects() if isinstance(o, t)]
 
 
-def _expand_template(contents, params):
-    tpl = jinja2.Template(source=contents,
-                          undefined=jinja2.StrictUndefined)
+def _expand_template(contents: str, params: dict[str, ty.Any]) -> ty.Any:
+    tpl = jinja2.Template(source=contents, undefined=jinja2.StrictUndefined)
     return tpl.render(**params)
 
 
+Reason = ty.TypedDict("Reason", {"reason": str, "details": str, "class": str})
+
+
 class Healthcheck(base.ConfigurableMiddleware):
     """Healthcheck application used for monitoring.
 
@@ -387,32 +397,44 @@ Reason
 </HTML>
 """
 
-    def __init__(self, *args, **kwargs):
-        super(Healthcheck, self).__init__(*args, **kwargs)
-        self.oslo_conf.register_opts(opts.HEALTHCHECK_OPTS,
-                                     group='healthcheck')
+    def __init__(
+        self,
+        application: WSGIApplication | None,
+        conf: dict[str, ty.Any] | cfg.ConfigOpts | None = None,
+    ) -> None:
+        super().__init__(application, conf)
+        self.oslo_conf.register_opts(
+            opts.HEALTHCHECK_OPTS, group='healthcheck'
+        )
         self._path = self._conf_get('path')
         self._show_details = self._conf_get('detailed')
         self._source_ranges = [
             ipaddress.ip_network(r)
-            for r in self._conf_get('allowed_source_ranges')]
+            for r in self._conf_get('allowed_source_ranges')
+        ]
         self._ignore_proxied_requests = self._conf_get(
-            'ignore_proxied_requests')
+            'ignore_proxied_requests'
+        )
 
         # (abhishekk): Verify that if `enable_by_files` and
         # `disable_by_file` backends are not enabled at same time.
         self._verify_configured_plugins()
 
         self._backends = stevedore.NamedExtensionManager(
-            self.NAMESPACE, self._conf_get('backends'),
-            name_order=True, invoke_on_load=True,
-            invoke_args=(self.oslo_conf, self.conf))
-        self._accept_to_functor = collections.OrderedDict([
-            # Order here matters...
-            ('text/plain', self._make_text_response),
-            ('text/html', self._make_html_response),
-            ('application/json', self._make_json_response),
-        ])
+            self.NAMESPACE,
+            self._conf_get('backends'),
+            name_order=True,
+            invoke_on_load=True,
+            invoke_args=(self.oslo_conf, self.conf),
+        )
+        self._accept_to_functor = collections.OrderedDict(
+            [
+                # Order here matters...
+                ('text/plain', self._make_text_response),
+                ('text/html', self._make_html_response),
+                ('application/json', self._make_json_response),
+            ]
+        )
         self._accept_order = tuple(self._accept_to_functor)
         # When no accept type matches instead of returning 406 we will
         # always return text/plain (because sending an error from this
@@ -420,27 +442,38 @@ Reason
         self._default_accept = 'text/plain'
         self._ignore_path = False
 
-    def _verify_configured_plugins(self):
+    def _verify_configured_plugins(self) -> None:
         backends = self._conf_get('backends')
         exclusive_plugins = ['disable_by_file', 'enable_by_files']
 
         if set(exclusive_plugins).issubset(set(backends)):
-            raise ConfigInvalid('`enable_by_files` plugin and '
-                                '`disable_by_file` plugin should not be '
-                                'enabled at the same time.')
+            raise ConfigInvalid(
+                '`enable_by_files` plugin and '
+                '`disable_by_file` plugin should not be '
+                'enabled at the same time.'
+            )
 
-    def _conf_get(self, key, group='healthcheck'):
-        return super(Healthcheck, self)._conf_get(key, group=group)
+    def _conf_get(self, key: str, group: str = 'healthcheck') -> ty.Any:
+        return super()._conf_get(key, group=group)
 
-    @removals.remove(
+    @removals.remove(  # type: ignore
         message="The healthcheck middleware must now be configured as "
-        "an application, not as a filter")
+        "an application, not as a filter"
+    )
     @classmethod
-    def factory(cls, global_conf, **local_conf):
-        return super(Healthcheck, cls).factory(global_conf, **local_conf)
+    def factory(
+        cls,
+        global_conf: dict[str, ty.Any] | None,
+        **local_conf: ty.Any,
+    ) -> ty.Callable[[WSGIApplication], base.ConfigurableMiddleware]:
+        return super().factory(global_conf, **local_conf)
 
     @classmethod
-    def app_factory(cls, global_conf, **local_conf):
+    def app_factory(
+        cls,
+        global_conf: dict[str, ty.Any] | None,
+        **local_conf: ty.Any,
+    ) -> ty_ext.Self:
         """Factory method for paste.deploy.
 
         :param global_conf: dict of options for all middlewares
@@ -452,12 +485,12 @@ Reason
         """
         conf = global_conf.copy() if global_conf else {}
         conf.update(local_conf)
-        o = cls(application=None, conf=conf)
-        o._ignore_path = True
-        return o
+        middleware = cls(None, conf)
+        middleware._ignore_path = True
+        return middleware
 
     @staticmethod
-    def _get_threadstacks():
+    def _get_threadstacks() -> list[ty.Any]:
         threadstacks = []
         try:
             active_frames = sys._current_frames()
@@ -473,7 +506,7 @@ Reason
         return threadstacks
 
     @staticmethod
-    def _get_greenstacks():
+    def _get_greenstacks() -> list[ty.Any]:
         greenstacks = []
         if greenlet is not None:
             buf = io.StringIO()
@@ -485,17 +518,23 @@ Reason
         return greenstacks
 
     @staticmethod
-    def _pretty_json_dumps(contents):
+    def _pretty_json_dumps(contents: dict[str, ty.Any]) -> str:
         return json.dumps(contents, indent=4, sort_keys=True)
 
     @staticmethod
-    def _are_results_healthy(results):
+    def _are_results_healthy(
+        results: list[pluginbase.HealthcheckResult],
+    ) -> bool:
         for result in results:
             if not result.available:
                 return False
         return True
 
-    def _make_text_response(self, results, healthy):
+    def _make_text_response(
+        self,
+        results: list[pluginbase.HealthcheckResult],
+        healthy: bool,
+    ) -> tuple[str, str]:
         params = {
             'reasons': [result.reason for result in results],
             'detailed': self._show_details,
@@ -503,7 +542,11 @@ Reason
         body = _expand_template(self.PLAIN_RESPONSE_TEMPLATE, params)
         return (body.strip(), 'text/plain')
 
-    def _make_json_response(self, results, healthy):
+    def _make_json_response(
+        self,
+        results: list[pluginbase.HealthcheckResult],
+        healthy: bool,
+    ) -> tuple[str, str]:
         if self._show_details:
             body = {
                 'detailed': True,
@@ -515,14 +558,17 @@ Reason
                     'threshold': gc.get_threshold(),
                 },
             }
-            reasons = []
+            reasons: list[Reason] = []
             for result in results:
-                reasons.append({
-                    'reason': result.reason,
-                    'details': result.details or '',
-                    'class': reflection.get_class_name(result,
-                                                       fully_qualified=False),
-                })
+                reasons.append(
+                    {
+                        'reason': result.reason,
+                        'details': result.details or '',
+                        'class': reflection.get_class_name(
+                            result, fully_qualified=False
+                        ),
+                    }
+                )
             body['reasons'] = reasons
             body['greenthreads'] = self._get_greenstacks()
             body['threads'] = self._get_threadstacks()
@@ -533,22 +579,33 @@ Reason
             }
         return (self._pretty_json_dumps(body), 'application/json')
 
-    def _make_head_response(self, results, healthy):
-        return ( "", "text/plain")
+    def _make_head_response(
+        self,
+        results: list[pluginbase.HealthcheckResult],
+        healthy: bool,
+    ) -> tuple[str, str]:
+        return ("", "text/plain")
 
-    def _make_html_response(self, results, healthy):
+    def _make_html_response(
+        self,
+        results: list[pluginbase.HealthcheckResult],
+        healthy: bool,
+    ) -> tuple[str, str]:
         try:
             hostname = socket.gethostname()
-        except socket.error:
+        except OSError:
             hostname = None
-        translated_results = []
+        translated_results: list[Reason] = []
         for result in results:
-            translated_results.append({
-                'details': result.details or '',
-                'reason': result.reason,
-                'class': reflection.get_class_name(result,
-                                                   fully_qualified=False),
-            })
+            translated_results.append(
+                {
+                    'reason': result.reason,
+                    'details': result.details or '',
+                    'class': reflection.get_class_name(
+                        result, fully_qualified=False
+                    ),
+                }
+            )
         params = {
             'healthy': healthy,
             'hostname': hostname,
@@ -560,19 +617,25 @@ Reason
             'gc': {
                 'counts': gc.get_count(),
                 'threshold': gc.get_threshold(),
-             },
-             'threads': self._get_threadstacks(),
-             'greenthreads': self._get_threadstacks(),
+            },
+            'threads': self._get_threadstacks(),
+            'greenthreads': self._get_threadstacks(),
         }
         body = _expand_template(self.HTML_RESPONSE_TEMPLATE, params)
         return (body.strip(), 'text/html')
 
     @webob.dec.wsgify
-    def process_request(self, req):
+    def process_request(  # type: ignore[override]
+        self,
+        req: webob.request.Request,
+    ) -> webob.response.Response | None:
         if not self._ignore_path and req.path != self._path:
             return None
 
         if self._source_ranges:
+            if not req.remote_addr:
+                return None
+
             remote_addr = ipaddress.ip_address(req.remote_addr)
             for r in self._source_ranges:
                 if r.version == remote_addr.version and remote_addr in r:
@@ -584,13 +647,18 @@ Reason
 
         if self._ignore_proxied_requests:
             for hdr in [
-                'FORWARDED', 'FORWARDED_PROTO', 'FORWARDED_HOST',
-                'FORWARDED_FOR', 'FORWARDED_PREFIX']:
-                if req.environ.get("HTTP_X_%s" % hdr):
+                'FORWARDED',
+                'FORWARDED_PROTO',
+                'FORWARDED_HOST',
+                'FORWARDED_FOR',
+                'FORWARDED_PREFIX',
+            ]:
+                if req.environ.get(f"HTTP_X_{hdr}"):
                     return None
 
-        results = [ext.obj.healthcheck(req.server_port)
-                   for ext in self._backends]
+        results = [
+            ext.obj.healthcheck(req.server_port) for ext in self._backends
+        ]
         healthy = self._are_results_healthy(results)
         if req.method == "HEAD":
             functor = self._make_head_response
@@ -604,6 +672,9 @@ Reason
                 accept_type = self._default_accept
             functor = self._accept_to_functor[accept_type]
         body, content_type = functor(results, healthy)
-        return webob.response.Response(status=status, body=body,
-                                       charset='UTF-8',
-                                       content_type=content_type)
+        return webob.response.Response(
+            status=str(status),
+            body=body,
+            charset='UTF-8',
+            content_type=content_type,
+        )
