@@ -17,7 +17,6 @@ from oslotest.base import BaseTestCase
 
 
 class TestOptionDiscovery(BaseTestCase):
-
     def test_all(self):
         opts.list_opts()
 
@@ -26,6 +25,3 @@ class TestOptionDiscovery(BaseTestCase):
 
     def test_cors(self):
         opts.list_opts_cors()
-
-    def test_ssl(self):
-        opts.list_opts_ssl()
